AuthClient class

Implemented types
Annotations
  • @Deprecated('walletconnect_flutter_v2 package is no longer maintened. Read more at: https://docs.reown.com/advanced/walletconnect-deprecations#flutter')

Constructors

AuthClient({required ICore core, required PairingMetadata metadata})

Properties

authKeys → IGenericStore<AuthPublicKey>
no setteroverride
authRequests → IGenericStore<PendingAuthRequest>
no setteroverride
completeRequests → IGenericStore<StoredCacao>
no setteroverride
core → ICore
no setteroverride
engine ↔ IAuthEngine
getter/setter pairoverride-getter
hashCode → int
The hash code for this object.
no setterinherited
metadata → PairingMetadata
no setteroverride
onAuthRequest → Event<AuthRequest>
no setteroverride
onAuthResponse → Event<AuthResponse>
no setteroverride
pairingTopics → IGenericStore<String>
no setteroverride
protocol → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int
no setteroverride

Methods

formatMessage({required String iss, required CacaoRequestPayload cacaoPayload}) → String
format payload to message string
override
getCompletedRequestsForPairing({required String pairingTopic}) → Map<int, StoredCacao>
override
getPendingRequests() → Map<int, PendingAuthRequest>
override
init() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request({required AuthRequestParams params, String? pairingTopic, List<List<String>>? methods = AuthEngine.DEFAULT_METHODS}) → Future<AuthRequestResponse>
override
respond({required int id, required String iss, CacaoSignature? signature, WalletConnectError? error}) → Future<void>
respond wallet authentication
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createInstance({required String projectId, String relayUrl = WalletConnectConstants.DEFAULT_RELAY_URL, required PairingMetadata metadata, bool memoryStore = false, IHttpClient httpClient = const HttpWrapper(), LogLevel logLevel = LogLevel.nothing}) → Future<AuthClient>