AuthEngine class

Implemented types
Annotations
  • @Deprecated('walletconnect_flutter_v2 package is no longer maintened. Read more at: https://docs.reown.com/advanced/walletconnect-deprecations#flutter')

Constructors

AuthEngine({required ICore core, required PairingMetadata metadata, required IGenericStore<AuthPublicKey> authKeys, required IGenericStore<String> pairingTopics, required IGenericStore<PendingAuthRequest> authRequests, required IGenericStore<StoredCacao> completeRequests})

Properties

authKeys ↔ IGenericStore<AuthPublicKey>
getter/setter pairoverride-getter
authRequests ↔ IGenericStore<PendingAuthRequest>
getter/setter pairoverride-getter
completeRequests ↔ IGenericStore<StoredCacao>
getter/setter pairoverride-getter
core → ICore
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → PairingMetadata
final
onAuthRequest → Event<AuthRequest>
final
onAuthResponse → Event<AuthResponse>
final
pairingTopics ↔ IGenericStore<String>
getter/setter pairoverride-getter
pendingAuthRequests ↔ List<AuthRequestCompleter>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatAuthMessage({required String iss, required CacaoRequestPayload cacaoPayload}) → String
format payload to message string
override
getCompletedRequestsForPairing({required String pairingTopic}) → Map<int, StoredCacao>
override
getPendingAuthRequests() → Map<int, PendingAuthRequest>
override
init() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestAuth({required AuthRequestParams params, String? pairingTopic, List<List<String>>? methods = DEFAULT_METHODS}) → Future<AuthRequestResponse>
override
respondAuthRequest({required int id, required String iss, CacaoSignature? signature, WalletConnectError? error}) → Future<void>
respond wallet authentication
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DEFAULT_METHODS → const List<List<String>>