IAuthClient class abstract

Implementers

Constructors

IAuthClient()

Properties

authKeys → IGenericStore<AuthPublicKey>
final
authRequests → IGenericStore<PendingAuthRequest>
final
completeRequests → IGenericStore<StoredCacao>
final
core → ICore
final
engine → IAuthEngine
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → PairingMetadata
final
onAuthRequest → Event<AuthRequest>
final
onAuthResponse → Event<AuthResponse>
final
pairingTopics → IGenericStore<String>
final
protocol → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int
final

Methods

formatMessage({required String iss, required CacaoRequestPayload cacaoPayload}) → String
format payload to message string
getCompletedRequestsForPairing({required String pairingTopic}) → Map<int, StoredCacao>
getPendingRequests() → Map<int, PendingAuthRequest>
init() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request({required AuthRequestParams params, String? pairingTopic, List<List<String>>? methods}) → Future<AuthRequestResponse>
respond({required int id, required String iss, CacaoSignature? signature, WalletConnectError? error}) → Future<void>
respond wallet authentication
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited