IAuthEngineApp class abstract

Inheritance
Implementers

Constructors

IAuthEngineApp()

Properties

authKeys → IGenericStore<AuthPublicKey>
finalinherited
completeRequests → IGenericStore<StoredCacao>
finalinherited
core → ICore
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
metadata → PairingMetadata
finalinherited
onAuthResponse → Event<AuthResponse>
final
pairingTopics → IGenericStore<String>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatAuthMessage({required String iss, required CacaoRequestPayload cacaoPayload}) → String
format payload to message string
inherited
getCompletedRequestsForPairing({required String pairingTopic}) → Map<int, StoredCacao>
inherited
init() → Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestAuth({required AuthRequestParams params, String? pairingTopic, List<List<String>>? methods}) → Future<AuthRequestResponse>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited