IAuthEngineCommon class abstract

Implementers

Constructors

IAuthEngineCommon()

Properties

authKeys → IGenericStore<AuthPublicKey>
final
completeRequests → IGenericStore<StoredCacao>
final
core → ICore
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → PairingMetadata
final
pairingTopics → IGenericStore<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatAuthMessage({required String iss, required CacaoRequestPayload cacaoPayload}) → String
format payload to message string
getCompletedRequestsForPairing({required String pairingTopic}) → Map<int, StoredCacao>
init() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited