EncodeOptions class

Constructors

EncodeOptions({int? type, String? senderPublicKey, String? receiverPublicKey})

Properties

hashCode → int
The hash code for this object.
no setterinherited
receiverPublicKey ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderPublicKey ↔ String?
getter/setter pair
type ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

TYPE_0 → const int
TYPE_1 → const int
TYPE_2 → const int