Verify class

Implemented types

Constructors

Verify({required ICore core, required IHttpClient httpClient})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getValidation(AttestationResponse? attestation, Uri? metadataUri) → Validation
override
init({String? verifyUrl}) → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve({required String attestationId}) → Future<AttestationResponse?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited