RpcOptions class

Annotations
  • @freezed

Constructors

RpcOptions({required int ttl, required bool prompt, required int tag})
const
factory

Properties

copyWith → $RpcOptionsCopyWith<RpcOptions>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
prompt → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → int
no setterinherited
ttl → int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited