WalletConnectError class

Annotations
  • @freezed

Constructors

WalletConnectError({required int code, required String message, String? data})
const
factory
WalletConnectError.fromJson(Map<String, dynamic> json)
factory

Properties

code → int
no setterinherited
copyWith → $WalletConnectErrorCopyWith<WalletConnectError>
no setterinherited
data → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited