AuthRequestParams class

Constructors

AuthRequestParams({required String chainId, required String domain, required String aud, String? nonce, String? type = CacaoHeader.EIP4361, String? nbf, String? exp, String? statement, String? requestId, List<String>? resources, int? expiry})

Properties

aud → String
The complete URL you are logging into. Example: https://example.com/login
final
chainId → String
The Chain ID. Examples: eip155:1 (Eth Mainnet), eip155:43114 (Avalanche)
final
domain → String
The domain you are logging in to. Example: example.com
final
exp → String?
final
expiry → int?
final
hashCode → int
The hash code for this object.
no setterinherited
nbf → String?
final
nonce → String
final
requestId → String?
final
resources → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statement → String?
final
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited