SessionAuthRequest class

Inheritance

Constructors

SessionAuthRequest({required int id, required String topic, required SessionAuthPayload authPayload, required ConnectionMetadata requester, TransportType transportType = TransportType.relay, VerifyContext? verifyContext})

Properties

authPayload → SessionAuthPayload
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
requester → ConnectionMetadata
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic → String
final
transportType → TransportType
final
verifyContext → VerifyContext?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited