PendingSessionAuthRequest class

Annotations
  • @freezed

Constructors

PendingSessionAuthRequest({required int id, required String pairingTopic, required ConnectionMetadata requester, required int expiryTimestamp, required CacaoRequestPayload authPayload, required VerifyContext verifyContext, @Default.new(TransportType.relay) TransportType transportType})
const
factory
PendingSessionAuthRequest.fromJson(Map<String, dynamic> json)
factory

Properties

authPayload → CacaoRequestPayload
no setterinherited
copyWith → $PendingSessionAuthRequestCopyWith<PendingSessionAuthRequest>
no setterinherited
expiryTimestamp → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setterinherited
pairingTopic → String
no setterinherited
requester → ConnectionMetadata
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transportType → TransportType
no setterinherited
verifyContext → VerifyContext
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited