ProposalData class

Annotations
  • @freezed

Constructors

ProposalData({required int id, required int expiry, required List<Relay> relays, required ConnectionMetadata proposer, required Map<String, RequiredNamespace> requiredNamespaces, required Map<String, RequiredNamespace> optionalNamespaces, required String pairingTopic, Map<String, String>? sessionProperties, Map<String, Namespace>? generatedNamespaces})
const
factory
ProposalData.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $ProposalDataCopyWith<ProposalData>
no setterinherited
expiry → int
no setterinherited
generatedNamespaces → Map<String, Namespace>?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setterinherited
optionalNamespaces → Map<String, RequiredNamespace>
no setterinherited
pairingTopic → String
no setterinherited
proposer → ConnectionMetadata
no setterinherited
relays → List<Relay>
no setterinherited
requiredNamespaces → Map<String, RequiredNamespace>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionProperties → Map<String, String>?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited