SessionProposal class

Annotations
  • @freezed

Constructors

SessionProposal({required int id, required ProposalData params})
const
factory
SessionProposal.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $SessionProposalCopyWith<SessionProposal>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setterinherited
params → ProposalData
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited