Namespace class

Annotations
  • @freezed

Constructors

Namespace({List<String>? chains, required List<String> accounts, required List<String> methods, required List<String> events})
const
factory
Namespace.fromJson(Map<String, dynamic> json)
factory

Properties

accounts → List<String>
no setterinherited
chains → List<String>?
no setterinherited
copyWith → $NamespaceCopyWith<Namespace>
no setterinherited
events → List<String>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
methods → List<String>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited