SessionData class

Annotations
  • @freezed

Constructors

SessionData({required String topic, required String pairingTopic, required Relay relay, required int expiry, required bool acknowledged, required String controller, required Map<String, Namespace> namespaces, required ConnectionMetadata self, required ConnectionMetadata peer, Map<String, RequiredNamespace>? requiredNamespaces, Map<String, RequiredNamespace>? optionalNamespaces, Map<String, String>? sessionProperties, List<Cacao>? authentication, @Default.new(TransportType.relay) TransportType transportType})
const
factory
SessionData.fromJson(Map<String, dynamic> json)
factory

Properties

acknowledged → bool
no setterinherited
authentication → List<Cacao>?
no setterinherited
controller → String
no setterinherited
copyWith → $SessionDataCopyWith<SessionData>
no setterinherited
expiry → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
namespaces → Map<String, Namespace>
no setterinherited
optionalNamespaces → Map<String, RequiredNamespace>?
no setterinherited
pairingTopic → String
no setterinherited
peer → ConnectionMetadata
no setterinherited
relay → Relay
no setterinherited
requiredNamespaces → Map<String, RequiredNamespace>?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
self → ConnectionMetadata
no setterinherited
sessionProperties → Map<String, String>?
no setterinherited
topic → String
no setterinherited
transportType → TransportType
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited