SessionProposalCompleter class

Constructors

SessionProposalCompleter({required int id, required String selfPublicKey, required String pairingTopic, required Map<String, RequiredNamespace> requiredNamespaces, required Map<String, RequiredNamespace> optionalNamespaces, required Completer completer, Map<String, String>? sessionProperties})
const

Properties

completer → Completer
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
optionalNamespaces → Map<String, RequiredNamespace>
final
pairingTopic → String
final
requiredNamespaces → Map<String, RequiredNamespace>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selfPublicKey → String
final
sessionProperties → Map<String, String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited