SessionRequest class

Annotations
  • @freezed

Constructors

SessionRequest({required int id, required String topic, required String method, required String chainId, required dynamic params, required VerifyContext verifyContext, @Default.new(TransportType.relay) TransportType transportType})
const
factory
SessionRequest.fromJson(Map<String, dynamic> json)
factory

Properties

chainId → String
no setterinherited
copyWith → $SessionRequestCopyWith<SessionRequest>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setterinherited
method → String
no setterinherited
params → dynamic
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic → String
no setterinherited
transportType → TransportType
no setterinherited
verifyContext → VerifyContext
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited