SessionUpdate class

Inheritance

Constructors

SessionUpdate(int id, String topic, Map<String, Namespace> namespaces)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
namespaces ↔ Map<String, Namespace>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited